==> haskell-dependent-sum-template-0.1.1.1-144-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dependent-sum-template
version:              0.1.1.1
visibility:           public
id:                   dependent-sum-template-0.1.1.1-2Zc2KeVammj6Wpte3yqiwO
key:                  dependent-sum-template-0.1.1.1-2Zc2KeVammj6Wpte3yqiwO
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:
    Template Haskell code to generate instances of classes in dependent-sum package

description:
    Template Haskell code to generate instances of classes in dependent-sum package, such as '\''GEq'\'' and '\''GCompare'\''.

category:             Unclassified
abi:                  f8563e2a4d5cde2a20dea09781da5963
exposed:              True
exposed-modules:      Data.GADT.Compare.TH Data.GADT.Show.TH
hidden-modules:       Data.Dependent.Sum.TH.Internal
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/dependent-sum-template-0.1.1.1

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/dependent-sum-template-0.1.1.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum-template
hs-libraries:         HSdependent-sum-template-0.1.1.1-2Zc2KeVammj6Wpte3yqiwO
depends:
    base-4.16.4.0 dependent-sum-0.7.2.0-3OB5NRwGyYcCMwlBoEa7Kw
    template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu
    th-extras-0.0.0.8-DU2TT5MvmcUT7F3t2hv6K

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum-template/html/dependent-sum-template.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum-template/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dependent-sum-template-0.1.1.1-154-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dependent-sum-template
version:              0.1.1.1
visibility:           public
id:                   dependent-sum-template-0.1.1.1-Ga7qLpkEK0C39KHVqLP6Hv
key:                  dependent-sum-template-0.1.1.1-Ga7qLpkEK0C39KHVqLP6Hv
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:
    Template Haskell code to generate instances of classes in dependent-sum package

description:
    Template Haskell code to generate instances of classes in dependent-sum package, such as '\''GEq'\'' and '\''GCompare'\''.

category:             Unclassified
abi:                  1249a22920390a81713d3dffa94541ed
exposed:              True
exposed-modules:      Data.GADT.Compare.TH Data.GADT.Show.TH
hidden-modules:       Data.Dependent.Sum.TH.Internal
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/dependent-sum-template-0.1.1.1

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/dependent-sum-template-0.1.1.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum-template
hs-libraries:         HSdependent-sum-template-0.1.1.1-Ga7qLpkEK0C39KHVqLP6Hv
depends:
    base-4.16.4.0 dependent-sum-0.7.2.0-4h4ovsdit139tuGeWWRjdC
    template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu
    th-extras-0.0.0.8-5PsGX1LsYHJAeBIfbdBVCt

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum-template/html/dependent-sum-template.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum-template/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
